@@ -1,7 +1,7 @@
 import json
 import os , sys, platform,shutil, cmd
 
-from rrshare.rqUtil import Singleton, Singleton_wraps
+from rrshare.rqUtil.rqSingleton import Singleton, Singleton_wraps
 
 # diffrence OS path
 path = os.path.expanduser('~')
@@ -35,7 +35,7 @@ setting = Setting().setting()
 
 if __name__ == '__main__':
     s = Setting()
-    print(id(s), id(Setting()))
+    #print(id(s), id(Setting()))
     print(s.setting()['TSPRO_TOKEN'])
 
     
